@@ -20,14 +20,15 @@ mod tests {
             field1: 0x69,
             field2: [12, 34, 56],
         };
-        let ltv_bytes = original_ltv.to_ltv();
+        let ltv_bytes = <ExampleStruct as LTVItem<{ ByteOrder::BE }>>::to_ltv(&original_ltv);
 
-        let new_ltv = ExampleStruct::from_ltv(10, &ltv_bytes).unwrap();
+        let new_ltv =
+            <ExampleStruct as LTVItem<{ ByteOrder::BE }>>::from_ltv(10, &ltv_bytes).unwrap();
         assert_eq!(original_ltv, new_ltv);
     }
 
     #[derive(Debug, Ltv, Default, PartialEq, Eq)]
-    #[object(id = 10, length_size = 1)]
+    #[object(id = 10, length_size = 1, byte_order=LE)]
     struct LTVObjectExample {
         #[ltv_field(1)]
         field1: u8,
@@ -68,7 +69,7 @@ mod tests {
     }
 
     #[derive(Debug, LtvCollection, PartialEq, Eq)]
-    #[object(byte_order=BE)]
+    #[object(byte_order=LE)]
     enum MyObjects {
         Object1(LTVObjectExample),
     }
@@ -180,7 +181,7 @@ mod tests {
         );
     }
 
-    #[derive(Debug, Ltv, Default, PartialEq, Eq)]
+    #[derive(Debug, Default, PartialEq, Eq, Ltv)]
     #[object(id = 1, length_size = 1)]
     struct ItemWithList {
         #[ltv_field_list(1)]
